browserutilities/downloadmgr/DownloadMgrUiLib/Src/UserInteractionsEventHandler.cpp
branchRCL_3
changeset 84 800203832575
parent 67 4917f9bf7995
child 93 79859ed3eea9
--- a/browserutilities/downloadmgr/DownloadMgrUiLib/Src/UserInteractionsEventHandler.cpp	Wed Jun 09 10:52:50 2010 +0300
+++ b/browserutilities/downloadmgr/DownloadMgrUiLib/Src/UserInteractionsEventHandler.cpp	Mon Jun 21 16:54:17 2010 +0300
@@ -1102,11 +1102,17 @@
                     }
 
 
-                // update EDlAttrDestFilename with new path
-                User::LeaveIfError
-		                ( iDownload.SetStringAttribute( EDlAttrDestFilename, *fileName ) );
-                // move file
-                User::LeaveIfError( iDownload.Move() );
+                TBool isProg(EFalse);
+                User::LeaveIfError( iDownload.GetBoolAttribute( EDlAttrProgressive, isProg ) );
+
+                // Move operation should be invoked by DL Manger if its not a progressive download. 
+                if( !isProg )
+                    {
+                    // update EDlAttrDestFilename with new path
+                    User::LeaveIfError
+                            ( iDownload.SetStringAttribute( EDlAttrDestFilename, *fileName ) );
+                    User::LeaveIfError( iDownload.Move() );
+                    }
           	    CleanupStack::PopAndDestroy( fileName ); // fileName
                 }
             }